@@ -50,7 +50,7 @@ class LearnSproutClient(object):
     self.request_session = requests.sessions.Session(
       headers={'User-Agent': constants.user_agent},
       params={"apikey": apikey},
-      verify=True
+      verify=(self.api_root_url == constants.default_root_url)
       )
     self.last_response = None
 
