@@ -7,9 +7,11 @@ from term import TermCollection
 from attendance import AttendanceCollection
 from course_grade import CourseGradeCollection
 from enrollment import EnrollmentCollection
+from period import PeriodCollection
+from attendance_code import AttendanceCodeCollection
 
 class School(ResourceInstance):
-  subresources = [CourseCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection, EnrollmentCollection]
+  subresources = [CourseCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection, EnrollmentCollection, PeriodCollection, AttendanceCodeCollection]
 
 
 class SchoolCollection(ResourceCollection):
