@@ -20,17 +20,20 @@ class TestResource(unittest.TestCase):
   def test_iter_all(self):
     """ Ensure iter_all functionality """
     client = TestIterAll()
-    result = client.iter_all(params = {'foo': 1})
-    self.assertEquals(result.params, {'foo': 1})
-    result2 = client.iter_all(params = {'bar': 1})
-    self.assertEquals(result2.params, {'bar': 1})
 
-    result3 = client.iter_all(since = 1)
-    self.assertEquals(result3.params, {'since': 1})
-    result4 = client.iter_all(since = 2)
-    self.assertEquals(result4.params, {'since': 2})
-    result5 = client.iter_all()
-    self.assertEquals(result5.params, {})
+    result = client.iter_all(params={'foo': 1})
+    self.assertIn('foo', result.params)
+    self.assertEqual(result.params['foo'], 1)
+
+    result2 = client.iter_all(params={'foo': 1, 'bar': 2})
+    self.assertIn('foo', result2.params)
+    self.assertIn('bar', result2.params)
+    self.assertEquals(result2.params['foo'], 1)
+    self.assertEquals(result2.params['bar'], 2)
+
+    result3 = client.iter_all(since=3)
+    self.assertIn('since', result3.params)
+    self.assertEquals(result3.params['since'], 3)
 
 if __name__ == '__main__':
   unittest.main()
